<template>
  <!-- 产品信息弹窗 -->
  <div>
    <el-dialog :title="title" :visible="visible" v-if="visible" :before-close="handleClose"
               :close-on-click-modal="false"
               custom-class="bbsl-location-dialog" width="80%">
      <div>
        <el-form ref="formInfo" :rules="rules" :model="params" label-width="150px">
          <el-row>
            <el-col :span="12">
              <el-form-item label="产品编码：" prop="code">
                <el-input maxlength="32" clearable placeholder="请输入产品编码" v-model="params.code">
                </el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="产品名称：" prop="name">
                <el-input maxlength="64" clearable placeholder="请输入产品名称" v-model="params.name">
                </el-input>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col :span="12">
              <el-form-item label="设备类型：" prop="deviceType">
                <el-select style="width: 100%" placeholder="请选择设备类型" clearable
                           v-model="params.deviceType">
                  <el-option v-for="item in deviceTypeList" :key="item.value" :label="item.name"
                             :value="item.value"></el-option>
                </el-select>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="智能分类：" prop="isIntellect">
                <el-select style="width: 100%" placeholder="请选择智能分类" clearable
                           v-model="params.isIntellect">
                  <el-option v-for="item in isIntellectList" :key="item.value" :label="item.name"
                             :value="item.value"></el-option>
                </el-select>
              </el-form-item>
            </el-col>
            <!-- <el-col :span="12">
                  <el-form-item
                    inline="true"
                    label="所属分类："
                    prop="fullName"
                  >
                    <el-input
                      clearable
                      disabled
                      placeholder="请输入所属分类"
                      v-model="params.fullName"
                    ></el-input>
                  </el-form-item>
                </el-col> -->
          </el-row>
          <el-row>
            <el-col :span="24">
              <el-form-item label="图标：" prop="icon">
                <svgIcon
                  icon-style="icon"
                  :icon-class="params.icon"
                  v-if="params.icon"
                  style="font-size: 24px; vertical-align: middle;margin-right: 10px; "
                />
                <el-button
                  class="choseIcons"
                  size="small"
                  @click="$refs.iconPanl.dialogVisible = true"
                  style="margin-right: 10px; vertical-align: middle"
                  title="选择图标"
                >
                  <!--              <i class="el-icon-picture-outline" v-show="!meunIcon"/>-->
                  <span> 选择图标</span>
                </el-button>
                <el-button
                  class="choseIcons"
                  size="small"
                  @click="clearIcon"
                  style="vertical-align: middle"
                  title="选择图标"
                >
                  <!--              <i class="el-icon-picture-outline" v-show="!meunIcon"/>-->
                  <span>取消图标</span>
                </el-button>


                <!-- <el-upload name="files" class="avatar-uploader" :action="uploadUrl"
                  :show-file-list="false" :headers="header" accept="image/jpg,image/jpeg,image/png"
                  :data="{flowKey: '', params: ''}" :on-success="handleAvatarSuccess"
                  :before-upload="beforeAvatarUpload">
                  <img v-if="params.icon" :src="this.icon" class="avatar"
                    style="width:20px,heigth:20px" />
                  <i v-else class="el-icon-plus avatar-uploader-icon"></i>
                </el-upload> -->
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col :span="24">
              <el-form-item label="备注：" prop="memo">
                <el-input maxlength="500" type="textarea" :autosize="{minRows: 4}" placeholder="请输入备注内容"
                          v-model="params.memo">
                </el-input>
              </el-form-item>
            </el-col>
          </el-row>

        </el-form>
      </div>
      <span slot="footer" class="dialog-footer">
				<el-button type="primary" @click="handleSave">保存</el-button>
				<el-button @click="handleClose">取 消</el-button>
			</span>
    </el-dialog>
    <IconPanl @select="choseIcon" ref="iconPanl" />
  </div>
</template>

<script>
import productManage from '@/api/device/productManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import utils from '@/hotent-ui-util.js'
import IconDialog from '@/components/dialog/IconDialog.vue'
import IconPanl from '@/components/selector/IconPanl.vue'
import {
  mapState
} from 'vuex'

export default {
  name: 'productManageModal',
  components: {
    IconDialog,
    IconPanl
  },
  data() {
    return {
      visible: false,
      isSaved: false,
      title: '新增',
      params: {
        name: '', //设备名称
        isIntellect: '', //智能分类
        typeId: '', //产品分类ID
        deviceType: '', //设备类型
        code: '', //产品编码
        memo: '', //备注
        id: null,
        fullName: '',
        icon: ''
      },
      previewUrl: window.context.portal + '/file/onlinePreviewController/v1/getFileById_',
      uploadUrl: window.context.portal + '/file/v1/fileUpload', // 服务器上传地址
      icon: '',
      activeCollapse1: '1',
      ctlTypeList: '',
      active: 1,
      deviceTypeList: [], //设备类型字段列表
      isIntellectList: [], //智能分类字段列表
      rules: {
        name: [{
          required: true,
          message: '请输入产品名称',
          trigger: 'blur'
        }],
        isIntellect: [{
          required: true,
          message: '请选择智能分类',
          trigger: 'blur'
        }],
        code: [{
          required: true,
          message: '请输入产品编码',
          trigger: 'blur'
        }],
        deviceType: [{
          required: true,
          message: '请选择设备类型',
          trigger: 'blur'
        }]
      }
    }
  },
  created() {
    this.deviceTypeList = dictUtils.getDictItemsFromCache('sblx')
    this.ctlTypeList = dictUtils.getDictItemsFromCache('kjlx')
    this.isIntellectList = dictUtils.getDictItemsFromCache('znfl')
  },
  mounted() {
  },
  computed: mapState({
    header: (state) => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),
  methods: {
    clearIcon() {
      this.params.icon = ''
    },
    choseIcon(icon) {
      this.params.icon = icon
    },
    handleAvatarSuccess(res, file) {
      this.$set(this.params, 'icon', res.fileId)
      this.icon = this.previewUrl + res.fileId
    },
    beforeAvatarUpload(file) {
      const isJPG =
        file.type === 'image/jpeg' ||
        file.type === 'image/png' ||
        file.type === 'image/jpg'
      const isLt1M = file.size / 1024 / 1024 < 1
      if (!isJPG) {
        this.$message.error('上传图片只能是 JPG 格式!')
      }
      if (!isLt1M) {
        this.$message.error('上传图片大小不能超过 1MB!')
      }
      return isJPG && isLt1M
    },
    add(userRow) {
      this.params.fullName = userRow.fullName
      this.params.typeId = userRow.id
      this.params.deviceType = this.deviceTypeList[0].value
      this.params.isIntellect = this.isIntellectList[0].value
      this.visible = true
    },
    // 保存产品信息
    handleSave() {
      this.isSaved = true
      this.$refs.formInfo.validate((valid) => {
        if (valid) {
          if (this.title === '新增') {
            productManage.addProductInfo(this.params).then((response) => {
              console.log(this.params)
              if (response.state) {
                this.$notify({
                  type: 'success',
                  message: '新增成功',
                  duration: 2000
                })
                this.handleClose()
                this.$emit('reload')
              } else {
              }
            })
          }
          if (this.title === '修改') {
            productManage.updateProductInfo(this.params).then((response) => {
              if (response.state) {
                this.$notify({
                  type: 'success',
                  message: '修改成功',
                  duration: 2000
                })
                this.handleClose()
                this.$emit('reload')
              } else {
              }
            })
          }
        } else {
          this.$notify({
            type: 'warning',
            message: '请完善表单信息！',
            duration: 2000
          })
        }
      })
    },
    edit(row) {
      this.params = utils.deepClone(row)
      console.log(this.params)
      this.params.id = row.id
      this.visible = true
      this.title = '修改'
      // 根据id查询产品信息
      if (this.title === '修改') {
        productManage.productTypeDetail(row.typeId).then((res) => {
          console.log(res)
          this.params.fullName = res.name
        })
      }
    },
    // 关闭新增人员窗口
    handleClose() {
      ;
      (this.params = {
        name: '', //设备名称
        isIntellect: '', //智能分类
        typeId: '', //产品分类ID
        deviceType: '', //设备类型
        code: '', //产品编码
        memo: '', //备注
        id: null,
        fullName: '',
        icon: ''
      }),
        (this.title = '新增')
      this.visible = false
      this.activeCollapse1 = '1'
    }
  }
}
</script>

<style lang="scss" scoped>
.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}

.company-type ::v-deep .el-checkbox-group {
  height: initial !important;
}

.column-box {
  color: #409eff;
  display: flex;
  justify-content: space-evenly;
}

.avatar {
  width: 24px;
  height: 24px;
}
</style>
